@@ -1,7 +1,6 @@
 from tcell_agent.instrumentation.decorators import safe_wrap_function
 from tcell_agent.rust.native_agent import get_native_lib
 from tcell_agent.events.server_agent_packages import ServerAgentPackagesEvent
-from tcell_agent.events.server_agent_details import ServerAgentDetailsEvent
 from tcell_agent.events.settings_event import SettingsEvent
 from tcell_agent.system_info import get_packages
 
@@ -21,10 +20,6 @@ def get_startup_events():
         add_packages_event,
         initial_events
     )
-    safe_wrap_function(
-        "Create ServerAgentDetailsEvent",
-        lambda: initial_events.append(ServerAgentDetailsEvent())
-    )
 
     safe_wrap_function(
         "SettingsEvent: native_lib_loaded",
