@@ -1,4 +1,5 @@
 _needs_instrumention = True
+_needs_additional_instrumentation = True
 _agent_has_started = False
 _default_charset = "utf-8"
 _test_mode = False
@@ -15,6 +16,15 @@ def set_has_been_instrumented():
     _needs_instrumention = False
 
 
+def need_after_agent_started_instrumentation():
+    return _needs_additional_instrumentation
+
+
+def set_after_agent_started_instrumentation():
+    global _needs_additional_instrumentation  # pylint: disable=global-statement
+    _needs_additional_instrumentation = False
+
+
 def has_agent_started():
     return _agent_has_started
 
