@@ -34,7 +34,7 @@ class CreateNativeAgentTest(unittest.TestCase):
                           return_value=None) as patched_log_message:
             with patch.dict('os.environ', {'TCELL_AGENT_CONFIG': '/tmp/non-existent-file',
                                            'TCELL_AGENT_LOG_ENABLED': 'false'}):
-                native_agent = create_native_agent()
+                native_agent = create_native_agent({})
                 self.assertTrue(patched_log_message.called)
                 args, kwargs = patched_log_message.call_args
                 self.assertEqual(kwargs, {})
